@@ -1,6 +1,6 @@
 import React from 'react';
 import { Document, StyleSheet, View } from '@react-pdf/renderer';
-import { get, startCase } from 'lodash';
+import { startCase } from 'lodash';
 
 import {
   ENCOUNTER_TYPE_LABELS,
@@ -8,7 +8,6 @@ import {
   DRUG_ROUTE_LABELS,
   NOTE_TYPES,
 } from '@tamanu/constants';
-import { formatShort, formatShortest, formatTime, parseDate } from '@tamanu/utils/dateTime';
 
 import { CertificateHeader, Watermark } from './Layout';
 import { LetterheadSection } from './LetterheadSection';
@@ -21,6 +20,7 @@ import { Footer } from './printComponents/Footer';
 import { useLanguageContext, withLanguageContext } from '../pdf/languageContext';
 import { Page } from '../pdf/Page';
 import { Text } from '../pdf/Text';
+import { formatShort, formatTime } from '@tamanu/utils/dateTime';
 
 const borderStyle = '1 solid black';
 
@@ -109,39 +109,8 @@ const tableStyles = StyleSheet.create({
   },
 });
 
-const getDateTitleArray = date => {
-  const parsedDate = parseDate(date);
-  const shortestDate = formatShortest(parsedDate);
-  const timeWithSeconds = formatTime(parsedDate);
-
-  return [shortestDate, timeWithSeconds.toLowerCase()];
-};
-
-const getVitalsColumn = (startIndex, getTranslation, recordedDates) => {
-  const dateArray = [...recordedDates].reverse().slice(startIndex, startIndex + 12);
-  return [
-    {
-      key: 'measure',
-      title: getTranslation('vitals.table.column.measure', 'Measure'),
-      accessor: ({ value }) => value,
-      style: { width: 140, },
-    },
-    ...dateArray
-      .sort((a, b) => b.localeCompare(a))
-      .map(date => ({
-        title: getDateTitleArray(date),
-        key: date,
-        accessor: cells => {
-          const { value } = cells[date];
-          return value || '-';
-        },
-        style: { width: 60 },
-      })),
-  ];
-};
-
-const Table = props => <View style={tableStyles.table} {...props} />;
-const Row = props => (
+const Table = (props) => <View style={tableStyles.table} {...props} />;
+const Row = (props) => (
   <View
     style={[tableStyles.row, props.width && { width: props.width, justifyContent: 'start' }]}
     {...props}
@@ -227,7 +196,7 @@ const DataTable = ({ data, columns, title, type }) => {
   return (
     <Table>
       <DataTableHeading columns={columns} title={title} width={width} />
-      {data.map(row => (
+      {data.map((row) => (
         <Row key={row.id} wrap={false} width={width}>
           {columns.map(({ key, accessor, style }) => (
             <Cell key={key} style={style}>
@@ -293,7 +262,7 @@ const NotesSection = ({ notes }) => {
       <View>
         <MultipageTableHeading title={getTranslation('general.notes.label', 'Notes')} />
         <Table>
-          {notes.map(note => (
+          {notes.map((note) => (
             <>
               <View minPresenceAhead={80} />
               <View style={tableStyles.notesRow} key={note.id}>
@@ -348,11 +317,11 @@ const EncounterRecordPrintoutComponent = ({
   notes,
   discharge,
   medications,
-  localisation,
+  getLocalisation,
   vitalsData,
   recordedDates,
+  getVitalsColumn,
 }) => {
-  const getLocalisation = (key) => get(localisation, key);
   const { getTranslation, getEnumTranslation } = useLanguageContext();
   const { watermark, logo } = certificateData;
 
@@ -368,7 +337,7 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'dateMoved',
         title: getTranslation('pdf.encounterRecord.dateAndTimeMoved', 'Date & time moved'),
-        accessor: ({ date }) => (date ? formatShort(date) : '--/--/----'),
+        accessor: ({ date }) => (date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----'),
         style: { width: '35%' },
       },
     ],
@@ -388,7 +357,7 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'dateMoved',
         title: getTranslation('pdf.encounterRecord.dateAndTimeMoved', 'Date & time moved'),
-        accessor: ({ date }) => (date ? formatShort(date) : '--/--/----'),
+        accessor: ({ date }) => (date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----'),
         style: { width: '35%' },
       },
     ],
@@ -466,9 +435,9 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'areaToBeImaged',
         title: getTranslation('imaging.areas.label', 'Areas to be imaged'),
-        accessor: imagingRequest =>
+        accessor: (imagingRequest) =>
           imagingRequest?.areas?.length
-            ? imagingRequest?.areas.map(area => area.name).join(', ')
+            ? imagingRequest?.areas.map((area) => area.name).join(', ')
             : imagingRequest?.areaNote,
         style: { width: '25%' },
       },
@@ -488,7 +457,7 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'completedDate',
         title: getTranslation('pdf.encounterRecord.completedDate', 'Completed date'),
-        accessor: imagingRequest =>
+        accessor: (imagingRequest) =>
           imagingRequest?.results[0]?.completedAt
             ? formatShort(imagingRequest?.results[0]?.completedAt)
             : '--/--/----',
@@ -534,17 +503,28 @@ const EncounterRecordPrintoutComponent = ({
       <Page size="A4" style={pageStyles.body} wrap>
         {watermark && <Watermark src={watermark} />}
         <MultiPageHeader
-          documentName={getTranslation('pdf.encounterRecord.title', 'Patient encounter record')}
+          documentName={
+            discharge
+              ? getTranslation('pdf.encounterRecord.title', 'Patient encounter record')
+              : getTranslation(
+                  'pdf.encounterProgressRecord.title',
+                  'Patient encounter progress record',
+                )
+          }
           patientId={patientData.displayId}
           patientName={getName(patientData)}
         />
         <CertificateHeader>
           <LetterheadSection
             logoSrc={logo}
-            certificateTitle={getTranslation(
-              'pdf.encounterRecord.title',
-              'Patient encounter record',
-            )}
+            certificateTitle={
+              discharge
+                ? getTranslation('pdf.encounterRecord.title', 'Patient encounter record')
+                : getTranslation(
+                    'pdf.encounterProgressRecord.title',
+                    'Patient encounter progress record',
+                  )
+            }
             letterheadConfig={certificateData}
           />
         </CertificateHeader>
@@ -610,13 +590,25 @@ const EncounterRecordPrintoutComponent = ({
       </Page>
       {vitalsData.length > 0 && recordedDates.length > 0 ? (
         <>
-          {[0, 12, 24, 36, 48].map(start => {
+          {[0, 12, 24, 36, 48].map((start) => {
             return recordedDates.length > start ? (
               <Page size="A4" orientation="landscape" style={pageStyles.body}>
+                <MultiPageHeader
+                  documentName={
+                    discharge
+                      ? getTranslation('pdf.encounterRecord.title', 'Patient encounter record')
+                      : getTranslation(
+                          'pdf.encounterProgressRecord.title',
+                          'Patient encounter progress record',
+                        )
+                  }
+                  patientId={patientData.displayId}
+                  patientName={getName(patientData)}
+                />
                 <TableSection
                   title={getTranslation('pdf.encounterRecord.section.vitals', 'Vitals')}
                   data={vitalsData}
-                  columns={getVitalsColumn(start, getTranslation, recordedDates)}
+                  columns={getVitalsColumn(start)}
                   type="vitals"
                 />
                 <Footer />
